import { useState, useEffect } from 'react';
import Taro from '@tarojs/taro';
import withLayout from '@/layout';
import { ScrollView, View, Block, Image } from '@tarojs/components';
import '@/assets/css/iconfont.css';
import { queryCityList } from '@/services/common';
import { dispatchCitySelected } from '@/actions/city';
import { useDispatch } from 'react-redux';
import './index.scss';

export default withLayout(() => {
  const dispatch = useDispatch();
  const [list, setList] = useState({});

  useEffect(() => {
    initData()
  }, [])

  function initData () {
    queryCityList().then((cityList) => {
      console.log(`ttt`, cityList)
      const t = cityList.reduce((prev, cur) => {
        if (prev[cur.initial]) {
          prev[cur.initial].push(cur)
        } else {
          prev[cur.initial] = [cur]
        }
        return prev
      }, {})

      setList(t)
    })
  }

  function handleSelected (item) {
    dispatchCitySelected(item)(dispatch).then(() => {
      Taro.navigateBack({
        delta: 1,
      })
    })
  }

  const keys = Object.keys(list)
  return (
    <View className='brandList'>
      <ScrollView
        style={{
          height: '100vh',
        }}
        scrollY
      >

        <View className='city-list'>
          {
            keys.map((key) => (
              <Block key={key}>
                <View className='city-initial'>{key}</View>
                {list[key].map((item) => (
                  <View key={item.id} className='city-item' onClick={() => handleSelected(item)}>
                    <Image mode='heightFix' src={null}></Image>
                    <text>{item.shortname}</text>
                  </View>
                ))}
              </Block>
            ))
          }
        </View>
      </ScrollView>
    </View>
  );
});
