import IMSDK from './sdk'
import initListeners from "./listeners"

function IM() {
  // 消息类型
  const MESSAGETYPE = {
    IMAGE: 'image',
    TEXT: 'text',
    CARD: 'card',
  }

  const sdk = IMSDK()
  const listeners = initListeners()

  let sendPerson;
  let timer;

  sdk.listen('onMessage', listeners.getListeners)

  return {
    MESSAGETYPE,
    init,
    listen: listeners.append,
    connect: sdk.connect,
    send,
    sendMessage,
  }

  function bindPerson(person) {
    sendPerson = person
  }

  function send(to) {
    return function(type = MESSAGETYPE.TEXT) {
      return function(message) {
        return sendMessage(to, message, type)
      }
    }
  }

  function sendMessage(to, message, type = MESSAGETYPE.TEXT) {
    return sdk.send(wrapData(to, message, type))
  }

  function wrapData(to, data, messageType) {
    return JSON.stringify({
      sendPerson,
      receivePerson: to,
      message: data,
      messageType,
      createDate: new Date().valueOf(),
    })
  }

  function init(personId) {
    // eslint-disable-next-line no-undef
    const url = `${WSS_HOST}/wx/chat/${personId}`  

    bindPerson(personId)

    if (timer) {
      clearInterval(timer)
    }

    timer = setInterval(() => {
      if (sdk.getState() !== sdk.STATE.OPEN) {
        im.connect({ url })
      } else {
        // sdk.send('ping')
      }
    }, 2 * 1000)
  }
}

const im = IM();
export default im;
